@@ -209,9 +209,7 @@ setMethod("show", "SpatialGrid", function(object) print.SpatialGrid(object))
 }
 
 # make a SpatialPolygons from a SpatialPixels - Kohris Sahlen workshop
-
-as.SpatialPolygons.SpatialPixels <- function(obj, proj4string=CRS(as.character(NA)))
-{
+as.SpatialPolygons.SpatialPixels <- function(obj) {
 	obj_crds <- coordinates(obj)
 	IDs <- IDvaluesSpatialPixels(obj)
 	nPolygons <- nrow(obj_crds)
@@ -225,13 +223,12 @@ as.SpatialPolygons.SpatialPixels <- function(obj, proj4string=CRS(as.character(N
 		yi <- obj_crds[i,2]
 		x <- c(xi-cS2x, xi-cS2x, xi+cS2x, xi+cS2x, xi-cS2x)
 		y <- c(yi-cS2y, yi+cS2y, yi+cS2y, yi-cS2y, yi-cS2y)
-		Srl[[i]] <- Polygons(list(Polygon(coords=cbind(x, y)
-#, proj4string=proj4string
-)), ID=IDs[i])
+		Srl[[i]] <- Polygons(list(Polygon(coords=cbind(x, y))), ID=IDs[i])
 	}
-	res <- as.SpatialPolygons.PolygonsList(Srl, proj4string=proj4string)
+	res <- as.SpatialPolygons.PolygonsList(Srl, proj4string=CRS(proj4string(obj)))
 	res
 }
+setAs("SpatialPixels", "SpatialPolygons", function(from) as.SpatialPolygons.SpatialPixels(from))
 
 IDvaluesSpatialPixels <- function(obj) {
 	if (!is(obj, "SpatialPixels"))
